.\" file MASS/gamma.shape.glm.d
.\" copyright (C) 1994-9 W. N. Venables and B. D. Ripley
.\"
.BG
.FN gamma.shape.glm
.TL
Estimate the Shape Parameter of the Gamma Distribution in a GLM Fit
.DN
Find the maximum likelihood estimate of the shape parameter of
the gamma distribution after fitting a `Gamma' generalized
linear model.
.CS
gamma.shape.glm(object, it.lim=10, 
		eps.max=sqrt(.Machine$single.eps), verbose=F, ...)
.RA
.AG object
Fitted model object from a `Gamma' family or `quasi' family with
`variance = mu^2'.
.OA
.AG it.lim
Upper limit on the number of iterations.
.AG eps.max
Maximum discrepancy between approximations for the iteration
process to continue. 
.AG verbose
If `T', causes successive iterations to be printed out.  The
initial estimate is taken from the deviance.
.AG ...
further arguments passed to or from other methods.
.RT
List of two components 
.RC alpha
the maximum likelihood estimate
.RC SE
the approximate standard error, the square-root of the reciprocal of
the observed information.
.DT
A glm fit for a Gamma family correctly calculates the maximum
likelihood estimate of the mean parameters but provides only a
crude estimate of the dispersion parameter.  This function takes
the results of the glm fit and solves the maximum likelihood
equation for the reciprocal of the dispersion parameter, which is
usually called the shape (or exponent) parameter.
.SA
`gamma.dispersion'
.EX
> clotting <- data.frame(
    u = c(5,10,15,20,30,40,60,80,100),
    lot1 = c(118,58,42,35,27,25,21,19,18),
    lot2 = c(69,35,26,21,18,16,13,12,12))
> clot1 <- glm(lot1 ~ log(u), data=clotting, family=Gamma)
> gamma.shape(clot1)
                
Alpha: 538.13
   SE: 253.60

> gm <- glm(Days + 0.1 ~ Age*Eth*Sex*Lrn, 
		quasi(link=log, variance=mu^2), quine)
> gamma.shape(gm, verbose=T)
Initial estimate: 1.0603 
Iter.  1  Alpha: 1.23840774338543 
Iter.  2  Alpha: 1.27699745778205 
Iter.  3  Alpha: 1.27834332265501 
Iter.  4  Alpha: 1.27834485787226 
               
Alpha: 1.27834
   SE: 0.13452
> summary(gm, dispersion = gamma.dispersion(gm))  # better summary
    ....
.KW models
.WR
