.\" file MASS/oats.d
.\" copyright (C) 1994-9 W. N. Venables and B. D. Ripley
.\"
.BG D
.FN oats
.TL
Data from an Oats Field Trial
.SH SUMMARY
The yield of oats from a split-plot field trial using three varieties and
four levels of manurial treatment.  The experiment was laid out in 6 blocks
of 3 main plots, each split into 4 sub-plots.  The varieties were applied
to the main plots and the manurial treatments to the sub-plots.
.SH "DATA DESCRIPTION"
This data frame contains the following columns:
.AG B
Blocks, levels I, II, III, IV, V and VI
.AG V
Varieties, 3 levels.
.AG N
Nitrogen (manurial) treatment, levels  0.0cwt, 0.2cwt, 0.4cwt and 0.6cwt,
showing the application in cwt/acre.
.AG Y
Yields in 1/4lbs per sub-plot, each of area 1/80 acre.
.SH SOURCE
Yates, F. (1935) Complex experiments,
.ul
Journal of the Royal Statistical Society Suppl.
\fB2\fR, 181-247.
.PP
Also given in 
.br
Yates, F. (1970) 
.ul
Experimental design: Selected papers of Frank Yates, C.B.E, F.R.S.
 London: Griffin.
.EX
oats1 <- aov(Y ~ N + V + B, data=oats)
summary(oats1)
multicomp(oats1, focus="V")
lmat <- matrix(c(0,-1,1,rep(0, 11), 0,0,-1,1, rep(0,10), 
                 0,0,0,-1,1,rep(0,9)),,3, dimnames=list(NULL, 
               c("0.2cwt-0.0cwt", "0.4cwt-0.2cwt", "0.6cwt-0.4cwt")))
multicomp(oats1, lmat=lmat, bounds="lower", comparisons="none")

oats <- oats
oats$Nf <- ordered(oats$N, levels=sort(levels(oats$N)))
oats.aov <- aov(Y ~ Nf*V + Error(B/V), data = oats, qr = T)
summary(oats.aov)
summary(oats.aov, split=list(Nf=list(L=1, Dev=2:3)))
par(mfrow=c(1,2), pty="s")
plot(fitted(oats.aov[[4]]), studres(oats.aov[[4]]))
abline(h=0, lty=2)
oats.pr <- proj(oats.aov)
qqnorm(oats.pr[[4]][,"Residuals"], ylab="Stratum 4 residuals")
qqline(oats.pr[[4]][,"Residuals"])

par(mfrow=c(1,1), pty="m")
oats.aov2 <- aov(Y ~ N + V + Error(B/V), data = oats, qr = T)
model.tables(oats.aov2, type = "means", se = T)

is.random(oats$B) <- T
varcomp(Y ~ N + V + B/V, data = oats)

.KW sysdata
.WR
