.\" file MASS/predict.qda.d
.\" copyright (C) 1994-9 W. N. Venables and B. D. Ripley
.\"
.BG
.FN predict.qda
.TL
Classify from Quadratic Discriminant Analysis
.DN
Classify multivariate observations in conjunction with `qda'
.CS
predict.qda(object, newdata, prior = object$prior,
  method = c("plug-in", "predictive", "debiased", "looCV"), ...)
.RA
.AG object
object of class `"qda"'
.OA
.AG newdata
data frame of cases to be classified or, if object
has a formula, a data frame with columns of the same names as the
variables used. A vector will be interpreted
as a row vector.  If newdata is missing, an attempt will be
made to retrieve the data used to fit the `qda' object.
.AG prior
The prior probabilities of the classes, by default the proportions in the
training set or what was set in the call to `qda'.
.AG method
This determines how the parameter estimation is handled. With `"plug-in"'
(the default) the usual unbiased parameter estimates are used and
assumed to be correct. With `"debiased"' an unbiased estimator of 
the log posterior probabilities is used, and with `"predictive"' the
parameter estimates are integrated out using a vague prior.  With
`"looCV"' the leave-one-out cross-validation fits to the original
dataset are computed and returned.
.AG ...
arguments based from or to other methods
.RT
a list with components
.RC class
The MAP classification (a factor)
.RC posterior
posterior probabilities for the classes
.DT
.ME predict qda
.PP
Missing values in `newdata' are handled by returning `NA' if the
quadratic discriminants cannot be evaluated. If `newdata' is omitted and
the `na.action' of the fit omitted cases, these will be omitted on the
prediction.
.SA
`qda', `lda', `predict.lda'
.EX
tr <- sample(1:50,25)
train <- rbind(iris[tr,,1],iris[tr,,2],iris[tr,,3])
test <- rbind(iris[-tr,,1],iris[-tr,,2],iris[-tr,,3])
cl <- factor(c(rep("s",25),rep("c",25), rep("v",25)))
zq <- qda(train, cl)
predict(zq, test)$class
.KW multivariate
.WR
