.\" file class/lvq2.d copyright (C) 1994-9 W. N. Venables and B. D. Ripley
.\"
.BG
.FN lvq2
.TL
Learning Vector Quantization 2.1
.DN
Moves examples in a codebook to better represent the training set.
.CS
lvq2(x, cl, codebk, niter=100 * nrow(codebk$x), alpha=0.03, win=0.3)
.RA
.AG x
a matrix or data frame of examples
.AG cl
a vector or factor of classifications for the examples
.AG codebk
a codebook
.OA
.AG niter
number of iterations
.AG alpha
constant for training
.AG win
a tolerance for the closeness of the two nearest vectors.
.RT
A codebook, represented as a list with components `x' and `cl'
giving the examples and classes.
.DT
Selects `niter' examples at random  with replacement, and adjusts the nearest
two examples in the codebook if one is correct and the other incorrect.
.SH REFERENCES
Kohonen, T. (1990) The self-organizing map.  
.ul
Proc. IEEE
\fB78\fR, 1464-1480.
.sp
Kohonen, T. (1995)
.ul
Self-Organizing Maps.
Springer, Berlin.
.SA
`lvqinit', `lvq1', `olvq1', `lvq3', `lvqtest'
.EX
train <- rbind(iris[1:25,,1],iris[1:25,,2],iris[1:25,,3])
test <- rbind(iris[26:50,,1],iris[26:50,,2],iris[26:50,,3])
cl <- factor(c(rep("s",25),rep("c",25), rep("v",25)))
cd <- lvqinit(train, cl, 10)
lvqtest(cd, train)
cd0 <- olvq1(train, cl, cd)
lvqtest(cd0, train)
cd2 <- lvq2(train, cl, cd0)
lvqtest(cd2, train)
.KW classif
.WR
